==> blesta-5.10.2.zip: blesta/components/modules/direct_admin/language/de_de/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_stats.no_results'] = 'Statistische Informationen sind derzeit nicht verfügbar.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Wert';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Feld';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Informationen';
$lang['DirectAdmin.tab_client_stats'] = 'Statistik';
$lang['DirectAdmin.edit_row.add_btn'] = 'Server bearbeiten';
$lang['DirectAdmin.edit_row.notes_title'] = 'Anmerkungen';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'entfernen';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Hostname';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Name Server';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Zusätzlichen Namensserver hinzufügen';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Namensserver';
$lang['DirectAdmin.edit_row.basic_title'] = 'Grundeinstellungen';
$lang['DirectAdmin.edit_row.box_title'] = 'DirectAdmin Server bearbeiten';
$lang['DirectAdmin.add_row.add_btn'] = 'Server hinzufügen';
$lang['DirectAdmin.add_row.notes_title'] = 'Anmerkungen';
$lang['DirectAdmin.add_row.remove_name_server'] = 'entfernen';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Hostname';
$lang['DirectAdmin.add_row.name_server_col'] = 'Name Server';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Zusätzlichen Namensserver hinzufügen';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Namensserver';
$lang['DirectAdmin.add_row.basic_title'] = 'Grundeinstellungen';
$lang['DirectAdmin.add_row.box_title'] = 'DirectAdmin Server hinzufügen';
$lang['DirectAdmin.row_meta.name_server'] = 'Namensserver %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Konto-Limit';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Verwenden Sie SSL für die Verbindung zur API (empfohlen)';
$lang['DirectAdmin.row_meta.password'] = 'Passwort';
$lang['DirectAdmin.row_meta.user_name'] = 'Name des Benutzers';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Hafen';
$lang['DirectAdmin.row_meta.host_name'] = 'Host-Name';
$lang['DirectAdmin.row_meta.server_name'] = 'Server-Etikett';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Sind Sie sicher, dass Sie diese Servergruppe löschen wollen?';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Sind Sie sicher, dass Sie diesen Server löschen wollen?';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Löschen';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Löschen';
$lang['DirectAdmin.manage.module_groups.edit'] = 'bearbeiten';
$lang['DirectAdmin.manage.module_rows.edit'] = 'bearbeiten';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Optionen';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Anzahl der Server';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Name der Gruppe';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Optionen';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Konten';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Host-Name';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Server-Etikett';
$lang['DirectAdmin.manage.module_groups_title'] = 'Server-Gruppen';
$lang['DirectAdmin.manage.module_rows_title'] = 'Server';
$lang['DirectAdmin.add_module_group'] = 'Server-Gruppe hinzufügen';
$lang['DirectAdmin.add_module_row'] = 'Server hinzufügen';
$lang['DirectAdmin.package_fields.ip_assign'] = 'zuweisen';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Gemeinsame';
$lang['DirectAdmin.package_fields.ip'] = 'IP-Adresse';
$lang['DirectAdmin.package_fields.package'] = 'DirectAdmin-Paket';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Wiederverkäufer';
$lang['DirectAdmin.package_fields.type_user'] = 'Benutzer';
$lang['DirectAdmin.package_fields.type'] = 'Konto-Typ';
$lang['DirectAdmin.service_info.option_login'] = 'Einloggen';
$lang['DirectAdmin.service_info.options'] = 'Optionen';
$lang['DirectAdmin.service_info.server'] = 'Server';
$lang['DirectAdmin.service_info.password'] = 'Passwort';
$lang['DirectAdmin.service_info.username'] = 'Benutzername';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Passwort generieren';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Passwort aktualisieren';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Bestätigen Sie Ihr Passwort';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Passwort';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Passwort ändern';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Passwort generieren';
$lang['DirectAdmin.service_field.email'] = 'E-Mail';
$lang['DirectAdmin.service_field.password'] = 'Passwort';
$lang['DirectAdmin.service_field.username'] = 'Benutzername';
$lang['DirectAdmin.service_field.domain'] = 'Bereich';
$lang['DirectAdmin.server_groups.no_results'] = 'Es gibt keine Servergruppen.';
$lang['DirectAdmin.servers.no_results'] = 'Es gibt keine Server.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Gleichmäßig auf die Server verteilen';
$lang['DirectAdmin.order_options.first'] = 'Erster nicht-ausgelasteter Server';
$lang['DirectAdmin.tab_client_actions'] = 'Aktionen';
$lang['DirectAdmin.tab_stats'] = 'Statistik';
$lang['DirectAdmin.module_group'] = 'Server-Gruppe';
$lang['DirectAdmin.module_row_plural'] = 'Server';
$lang['DirectAdmin.module_row'] = 'Server';
$lang['DirectAdmin.description'] = 'DirectAdmin ist ein grafisches, webbasiertes Webhosting-Kontrollpanel, das die Verwaltung von Websites erleichtert.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.!error.change_package.type'] = 'Das Modul unterstützt nicht den Wechsel zwischen Nutzer- und Wiederverkäuferpaketen.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Bitte geben Sie eine gültige E-Mail Adresse ein.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Kennwort und Bestätigungskennwort stimmen nicht überein.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Stellen Sie sicher, dass das Passwort Folgendes enthält: Mindestens 12 Zeichen, mindestens 1 Großbuchstabe A-Z, mindestens 1 Kleinbuchstabe a-z, mindestens 1 Zahl 0-9 und mindestens 1 Sonderzeichen aus der Menge: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Der Nutzername muss zwischen 4 und 8 Zeichen lang sein.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Der Nutzername darf nur alphanumerische Zeichen enthalten.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Bitte geben Sie einen gültigen Domainnamen in der Form: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Eine IP-Adresse ist erforderlich.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Ein DirectAdmin-Paket ist erforderlich.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Kontotyp muss entweder Benutzer oder Wiederverkäufer sein.';
$lang['DirectAdmin.!error.api.internal'] = 'Es ist ein interner Fehler aufgetreten, oder der Server hat nicht auf die Anfrage geantwortet.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Sie müssen mindestens 2 Nameserver definieren.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Einer oder mehrere der eingegebenen Nameserver sind ungültig.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Kontolimit muss leer gelassen werden (für unbegrenzte Konten) oder auf einen ganzzahligen Wert gesetzt werden.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'SSL verwenden muss entweder true oder false sein.';
$lang['DirectAdmin.!error.password.format'] = 'Sie müssen ein Passwort eingeben.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Sie müssen einen Benutzernamen eingeben.';
$lang['DirectAdmin.!error.port.format'] = 'Der Anschluss muss eine Nummer sein.';
$lang['DirectAdmin.!error.host_name.format'] = 'Der Hostname scheint ungültig zu sein.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Sie müssen ein Server-Label eingeben.';

==> blesta-5.11.4.zip: blesta/components/modules/direct_admin/language/de_de/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_stats.no_results'] = 'Statistische Informationen sind derzeit nicht verfügbar.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Wert';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Feld';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Informationen';
$lang['DirectAdmin.tab_client_stats'] = 'Statistik';
$lang['DirectAdmin.edit_row.add_btn'] = 'Server bearbeiten';
$lang['DirectAdmin.edit_row.notes_title'] = 'Anmerkungen';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'entfernen';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Hostname';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Name Server';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Zusätzlichen Namensserver hinzufügen';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Namensserver';
$lang['DirectAdmin.edit_row.basic_title'] = 'Grundeinstellungen';
$lang['DirectAdmin.edit_row.box_title'] = 'DirectAdmin Server bearbeiten';
$lang['DirectAdmin.add_row.add_btn'] = 'Server hinzufügen';
$lang['DirectAdmin.add_row.notes_title'] = 'Anmerkungen';
$lang['DirectAdmin.add_row.remove_name_server'] = 'entfernen';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Hostname';
$lang['DirectAdmin.add_row.name_server_col'] = 'Name Server';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Zusätzlichen Namensserver hinzufügen';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Namensserver';
$lang['DirectAdmin.add_row.basic_title'] = 'Grundeinstellungen';
$lang['DirectAdmin.add_row.box_title'] = 'DirectAdmin Server hinzufügen';
$lang['DirectAdmin.row_meta.name_server'] = 'Namensserver %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Konto-Limit';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Verwenden Sie SSL für die Verbindung zur API (empfohlen)';
$lang['DirectAdmin.row_meta.password'] = 'Passwort';
$lang['DirectAdmin.row_meta.user_name'] = 'Name des Benutzers';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Hafen';
$lang['DirectAdmin.row_meta.host_name'] = 'Host-Name';
$lang['DirectAdmin.row_meta.server_name'] = 'Server-Etikett';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Sind Sie sicher, dass Sie diese Servergruppe löschen wollen?';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Sind Sie sicher, dass Sie diesen Server löschen wollen?';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Löschen';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Löschen';
$lang['DirectAdmin.manage.module_groups.edit'] = 'bearbeiten';
$lang['DirectAdmin.manage.module_rows.edit'] = 'bearbeiten';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Optionen';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Anzahl der Server';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Name der Gruppe';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Optionen';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Konten';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Host-Name';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Server-Etikett';
$lang['DirectAdmin.manage.module_groups_title'] = 'Server-Gruppen';
$lang['DirectAdmin.manage.module_rows_title'] = 'Server';
$lang['DirectAdmin.add_module_group'] = 'Server-Gruppe hinzufügen';
$lang['DirectAdmin.add_module_row'] = 'Server hinzufügen';
$lang['DirectAdmin.package_fields.ip_assign'] = 'zuweisen';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Gemeinsame';
$lang['DirectAdmin.package_fields.ip'] = 'IP-Adresse';
$lang['DirectAdmin.package_fields.package'] = 'DirectAdmin-Paket';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Wiederverkäufer';
$lang['DirectAdmin.package_fields.type_user'] = 'Benutzer';
$lang['DirectAdmin.package_fields.type'] = 'Konto-Typ';
$lang['DirectAdmin.service_info.option_login'] = 'Einloggen';
$lang['DirectAdmin.service_info.options'] = 'Optionen';
$lang['DirectAdmin.service_info.server'] = 'Server';
$lang['DirectAdmin.service_info.password'] = 'Passwort';
$lang['DirectAdmin.service_info.username'] = 'Benutzername';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Passwort generieren';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Passwort aktualisieren';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Bestätigen Sie Ihr Passwort';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Passwort';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Passwort ändern';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Passwort generieren';
$lang['DirectAdmin.service_field.email'] = 'E-Mail';
$lang['DirectAdmin.service_field.password'] = 'Passwort';
$lang['DirectAdmin.service_field.username'] = 'Benutzername';
$lang['DirectAdmin.service_field.domain'] = 'Bereich';
$lang['DirectAdmin.server_groups.no_results'] = 'Es gibt keine Servergruppen.';
$lang['DirectAdmin.servers.no_results'] = 'Es gibt keine Server.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Gleichmäßig auf die Server verteilen';
$lang['DirectAdmin.order_options.first'] = 'Erster nicht-ausgelasteter Server';
$lang['DirectAdmin.tab_client_actions'] = 'Aktionen';
$lang['DirectAdmin.tab_stats'] = 'Statistik';
$lang['DirectAdmin.module_group'] = 'Server-Gruppe';
$lang['DirectAdmin.module_row_plural'] = 'Server';
$lang['DirectAdmin.module_row'] = 'Server';
$lang['DirectAdmin.description'] = 'DirectAdmin ist ein grafisches, webbasiertes Webhosting-Kontrollpanel, das die Verwaltung von Websites erleichtert.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.!error.change_package.type'] = 'Das Modul unterstützt nicht den Wechsel zwischen Nutzer- und Wiederverkäuferpaketen.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Bitte geben Sie eine gültige E-Mail Adresse ein.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Kennwort und Bestätigungskennwort stimmen nicht überein.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Stellen Sie sicher, dass das Passwort Folgendes enthält: Mindestens 12 Zeichen, mindestens 1 Großbuchstabe A-Z, mindestens 1 Kleinbuchstabe a-z, mindestens 1 Zahl 0-9 und mindestens 1 Sonderzeichen aus der Menge: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Der Nutzername muss zwischen 4 und 8 Zeichen lang sein.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Der Nutzername darf nur alphanumerische Zeichen enthalten.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Bitte geben Sie einen gültigen Domainnamen in der Form: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Eine IP-Adresse ist erforderlich.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Ein DirectAdmin-Paket ist erforderlich.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Kontotyp muss entweder Benutzer oder Wiederverkäufer sein.';
$lang['DirectAdmin.!error.api.internal'] = 'Es ist ein interner Fehler aufgetreten, oder der Server hat nicht auf die Anfrage geantwortet.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Sie müssen mindestens 2 Nameserver definieren.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Einer oder mehrere der eingegebenen Nameserver sind ungültig.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Kontolimit muss leer gelassen werden (für unbegrenzte Konten) oder auf einen ganzzahligen Wert gesetzt werden.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'SSL verwenden muss entweder true oder false sein.';
$lang['DirectAdmin.!error.password.format'] = 'Sie müssen ein Passwort eingeben.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Sie müssen einen Benutzernamen eingeben.';
$lang['DirectAdmin.!error.port.format'] = 'Der Anschluss muss eine Nummer sein.';
$lang['DirectAdmin.!error.host_name.format'] = 'Der Hostname scheint ungültig zu sein.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Sie müssen ein Server-Label eingeben.';
$lang['DirectAdmin.row_meta.ip_address'] = 'IP-Adresse';
$lang['DirectAdmin.!error.ip_address.format'] = 'Die IP-Adresse scheint ungültig zu sein.';
